@@ -318,9 +318,10 @@ void pagecat_op(int op, int x, int y)
 	       schemassoc(topobject, areastruct.stack->thisinst->thisobject);
 	       /* pop back to calling (symbol) page */
 	       catreturn();
-	       eventmode = MOVE_MODE;
+	       eventmode = NORMAL_MODE;
 	    }
 	    else {
+	       areastruct.lastlibrary = bpage;
 	       startcatalog(NULL, (pointertype)(LIBRARY + bpage), NULL);
 	    }
 	    return;
@@ -336,7 +337,6 @@ void pagecat_op(int op, int x, int y)
 	    eventmode = NORMAL_MODE;
 	    if (mode == PAGELIB) {
 	       newpage(bpage);
-      	       eventmode = MOVE_MODE;
 	    }
 	    else {
 	       startcatalog(NULL, (pointertype)(LIBRARY + bpage), NULL);
@@ -1411,7 +1411,7 @@ void catalog_op(int op, int x, int y)
 		  schemassoc(topobject, (*libobj)->thisobject); 
    	          setpage(TRUE);
 		  catreturn();
-		  eventmode = MOVE_MODE;
+		  eventmode = NORMAL_MODE;
 	       }
 	       else if ((op == XCF_Library_Pop) || (op == XCF_Library_Copy)) {
 
@@ -1480,6 +1480,7 @@ void catalog_op(int op, int x, int y)
 	          }
 	          else {
                      eventmode = MOVE_MODE;
+	             areastruct.editcycle = 1;
 	          }
 #ifdef TCL_WRAPPER
 		  /* fprintf(stderr, "Creating event handler for xctk_drag: "); */
