@@ -631,7 +631,8 @@ typedef struct {
 typedef struct _objlist *objlistptr;
 
 typedef struct _objlist {
-   objectptr	thisobject;
+   int		libno;		/* library in which object appears */
+   objectptr	thisobject;	/* pointer to the object */
    objlistptr	next;
 } objlist;
 
@@ -1340,6 +1341,7 @@ typedef struct _undostack {
 /* the library page, and not be destroyed on every call to "composelib"	*/
 
 typedef struct {
+   char		*filename;	/* Last file loaded into the library */
    short	number;
    objectptr	*library;
    liblistptr	instlist;	/* List of instances */
